__title__ = "videohash"
__description__ = "Video Hashing Library"
__url__ = "https://akamhy.github.io/videohash/"
__version__ = "1.0.1"
__author__ = "akamhy"
__author_email__ = "akamhy@yahoo.com"
__license__ = "MIT"
__copyright__ = "Copyright 2021 Akash Mahanty et al."
